Home
last modified time | relevance | path

Searched refs:__attribute (Results 1 – 23 of 23) sorted by relevance

/freebsd-12.1/contrib/libstdc++/libmath/
H A Dmathconf.h73 typedef unsigned int U_int32_t __attribute ((mode (SI))); typedef
74 typedef int Int32_t __attribute ((mode (SI))); typedef
75 typedef unsigned int U_int64_t __attribute ((mode (DI))); typedef
76 typedef int Int64_t __attribute ((mode (DI))); typedef
/freebsd-12.1/contrib/libgnuregex/
H A Dregex_internal.h126 # define __attribute(arg) __attribute__ (arg) macro
128 # define __attribute(arg) macro
382 # define internal_function __attribute ((regparm (3), stdcall))
401 internal_function __attribute ((pure));
719 internal_function __attribute ((pure)) in internal_function()
732 internal_function __attribute ((pure)) in internal_function()
742 internal_function __attribute ((pure)) in internal_function()
H A Dregex_internal.c834 internal_function __attribute ((pure)) in internal_function()
1356 internal_function __attribute ((pure)) in internal_function()
1371 internal_function __attribute ((pure)) in internal_function()
H A Dregcomp.c289 __attribute ((always_inline)) in weak_alias()
2783 __attribute ((always_inline)) in parse_bracket_exp()
2809 __attribute ((always_inline)) in parse_bracket_exp()
2877 __attribute ((always_inline)) in parse_bracket_exp()
2957 __attribute ((always_inline)) in parse_bracket_exp()
H A Dregexec.c1051 __attribute ((always_inline)) internal_function
/freebsd-12.1/contrib/libpcap/pcap/
H A Dfuncattrs.h172 #define PCAP_NORETURN __attribute((noreturn))
173 #define PCAP_NORETURN_DEF __attribute((noreturn))
/freebsd-12.1/contrib/gcclibs/libmudflap/
H A Dmf-runtime.h89 __attribute((nothrow));
91 __attribute((nothrow));
93 __attribute((nothrow));
/freebsd-12.1/contrib/llvm/tools/clang/lib/Headers/
H A D__clang_cuda_runtime_wrapper.h355 __device__ void free(void *) __attribute((nothrow));
356 __device__ void *malloc(size_t) __attribute((nothrow)) __attribute__((malloc));
/freebsd-12.1/contrib/tcpdump/
H A Dfuncattrs.h78 #define NORETURN __attribute((noreturn))
H A Dconfigure3648 main(int argc __attribute((unused)), char **argv __attribute((unused)))
/freebsd-12.1/contrib/compiler-rt/lib/profile/
H A DInstrProfilingPort.h32 #define COMPILER_RT_ALWAYS_INLINE inline __attribute((always_inline))
/freebsd-12.1/sbin/routed/rtquery/
H A Drtquery.c129 static void trace_loop(char *argv[]) __attribute((__noreturn__));
130 static void query_loop(char *argv[], int) __attribute((__noreturn__));
/freebsd-12.1/sys/contrib/octeon-sdk/
H A Dcvmx-debug.c115 static char cvmx_debug_stack[8*1024] __attribute ((aligned (16)));
133 static char cvmx_debug_stack_all[CVMX_MAX_CORES][8*1024] __attribute ((aligned (16)));
/freebsd-12.1/contrib/llvm/include/llvm/ADT/
H A DStringRef.h880 __attribute((enable_if(__builtin_strlen(Str) == N - 1, in StringLiteral()
/freebsd-12.1/contrib/llvm/tools/clang/include/clang/Basic/
H A DTokenKinds.def400 KEYWORD(__attribute , KEYALL)
594 ALIAS("__attribute__", __attribute, KEYALL)
/freebsd-12.1/crypto/openssl/crypto/ec/
H A Decp_nistz256.c35 # define ALIGN32 __attribute((aligned(32)))
H A Decp_nistz256_table.c25 __attribute((aligned(4096)))
/freebsd-12.1/contrib/xz/
H A DChangeLog4563 Add underscores to attributes (__attribute((__foo__))).
/freebsd-12.1/contrib/gcc/cp/
H A DChangeLog1614 (cp_parser_type_specifier): Allow 'enum __attribute ((...)) E'.
/freebsd-12.1/contrib/gcc/doc/
H A Dextend.texi11138 A using-directive with @code{__attribute ((strong))} is stronger
11163 using namespace debug __attribute ((__strong__));
H A Dtm.texi8785 @code{__declspec(X)} as equivalent to @code{__attribute((X))}. By
H A Dinvoke.texi13638 effective to use @samp{__attribute ((visibility))} and/or
/freebsd-12.1/contrib/ntp/
H A DCommitLog128339 mark isc_assertioncallback_t __attribute((__noreturn__))
128342 add __attribute((__noreturn__)) to __attribute__ compat header snippet.
128348 Mark isc_assertioncallback_t __attribute((__noreturn__))